TypedBus class

/ TypedBus singleton

Constructors

TypedBus()
/ Factory constructor for singleton access
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
/ Dispose all controllers
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publish<T>(String event, T data) → void
/ Publish an event with strict type checking
subscribe<T>(String event) Stream<T>
/ Subscribe to an event
subscribeRaw(String event) Stream
/ Subscribe without type casting (raw stream)
toString() String
A string representation of this object.
inherited
wildFire(String event, dynamic data) → void
/ Publish an event with loose type checking (raw data)

Operators

operator ==(Object other) bool
The equality operator.
inherited