TypedBusEvents class
/ TypedBusEvents manages registering event payloads types
Constructors
- TypedBusEvents()
-
/ Factory constructor for singleton access
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getEventType(
String event) → Type? - / Get event type by registered event name
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerEvent<
T> (String event) → void - / Register an event with its payload type
-
toString(
) → String -
A string representation of this object.
inherited
-
validateEvent<
T> (String event) → void - / Validate the type of a registered event
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited